package ch.epfl.tpp.sol;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public final class Histogram {
    private final Map<Integer, Integer> valueCount;
    private final int minValue, maxValue;
    
    public Histogram(List<Integer> values) {
        int minValue = Integer.MAX_VALUE, maxValue = Integer.MIN_VALUE;
        Map<Integer, Integer> valueCount = new HashMap<>();
        for (int value: values) {
            minValue = Math.min(minValue, value);
            maxValue = Math.max(maxValue, value);
            if (valueCount.containsKey(value))
                valueCount.put(value, valueCount.get(value) + 1);
            else
                valueCount.put(value, 1);
        }
        
        this.valueCount = valueCount;
        this.minValue = minValue;
        this.maxValue = maxValue;
    }
    
    public int minValue() {
        if (valueCount.isEmpty())
            throw new IllegalStateException("no data, minimum index undefined");
        return minValue;
    }

    public int maxValue() {
        if (valueCount.isEmpty())
            throw new IllegalStateException("no data, maximum index undefined");
        return maxValue;
    }
    
    public int valueCount(int value) {
        Integer count = valueCount.get(value);
        return count == null ? 0 : count;
    }
}
