package ch.epfl.tpp.sol.image;

import ch.epfl.tpp.sol.Color;
import ch.epfl.tpp.sol.Point;

public final class HorizontalCompositeImage extends AbstractImage {
    private final Image left, right;
    private final double width, height;
    private final Color defaultColor;

    public HorizontalCompositeImage(Image left, Image right, Color defaultColor) {
        this.left = left;
        this.right = right;
        this.width = left.width() + right.width();
        this.height = Math.max(left.height(), right.height());
        this.defaultColor = defaultColor;
    }
    
    @Override
    public double width() {
        return width;
    }

    @Override
    public double height() {
        return height;
    }

    @Override
    public Color colorAtPoint(Point p) {
        checkContainedPoint(p);
        if (left.containsPoint(p)) {
            return left.colorAtPoint(p);
        } else {
            Point pR = p.translated(-left.width(), 0);
            return right.containsPoint(pR) ? right.colorAtPoint(pR) : defaultColor;
        }
    }
}
